<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Employee\Actions\AttendanceAction;
use Bixo\Employee\Http\Requests\AttendanceActionRequest;
use Bixo\Employee\Http\Resources\AttendanceResource;
use Bixo\Employee\Models\Attendance;

/**
 * Admin web controller class.
 */
class AttendanceActionController extends BaseController
{

    /**
     * Action controller function for attendance.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AttendanceActionRequest $request, Attendance $attendance, $action)
    {
        try {
            $request = $request->all();
            $attendance = AttendanceAction::run($action, $attendance, $request);

            $data = new AttendanceResource($attendance);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('employee::attendance.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('employee/attendance/' . $attendance->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('employee/attendance/' . $attendance->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
