<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Employee\Actions\EmployeeAction;
use Bixo\Employee\Http\Requests\EmployeeActionRequest;
use Bixo\Employee\Http\Resources\EmployeeResource;
use Bixo\Employee\Models\Employee;

/**
 * Admin web controller class.
 */
class EmployeeActionController extends BaseController
{

    /**
     * Action controller function for employee.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(EmployeeActionRequest $request, Employee $employee, $action)
    {
        try {
            $request = $request->all();
            $employee = EmployeeAction::run($action, $employee, $request);

            $data = new EmployeeResource($employee);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('employee::employee.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('employee/employee/' . $employee->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('employee/employee/' . $employee->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
