<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Employee\Actions\EmployeeReport;
use Bixo\Employee\Http\Requests\EmployeeReportRequest;

/**
 * Admin web controller class.
 */
class EmployeeReportController extends BaseController
{
    /**
     * Action controller function for employee.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(EmployeeReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Employee::class);
            $data = EmployeeReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('employee::employee.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('employee/employee/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('employee/employee/' . $report))
                ->redirect();
        }
    }
}
