<?php

namespace Bixo\Employee\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Employee\Events\EmployeeAction as EmployeeActionEvent;
use Bixo\Employee\Notifications\EmployeeAction as EmployeeActionNotification;
use Litepie\Actions\Concerns\AsAction;

class EmployeeAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the EmployeeActionEvent.
     *
     * @param   EmployeeActionEvent  $event
     * @return mixed
     */
    public function handle(EmployeeActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $employee.
     *
     * @param   EmployeeActionEvent  $event
     * @return void
     */
    public function create(EmployeeActionEvent $event)
    {
        $client = $event->employee->client;
        Notification::send($client, new EmployeeActionNotification($event));
    }

    /**
     * Handle the EmployeeActionEvent as a listener.
     *
     * @param   EmployeeActionEvent  $event
     * @return mixed
     */
    public function asListener(EmployeeActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   EmployeeActionEvent  $event
     * @return bool
     */
    private function isAllowed(EmployeeActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
