<?php

namespace Bixo\Employee\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Employee\Events\EmployeeWorkflow as EmployeeWorkflowEvent;
use Bixo\Employee\Notifications\EmployeeWorkflow as EmployeeWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class EmployeeWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(EmployeeWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $employee is submitted.
     *
     * @param EmployeeWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(EmployeeWorkflowEvent $event)
    {
        $client = $event->employee->client;
        Notification::send($client, new EmployeeWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $employee is published.
     *
     * @param EmployeeWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(EmployeeWorkflowEvent $event)
    {
        $client = $event->employee->client;
        Notification::send($client, new EmployeeWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $employee is approved.
     *
     * @param EmployeeWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(EmployeeWorkflowEvent $event)
    {
        $client = $event->employee->client;
        Notification::send($client, new EmployeeWorkflowNotification($event));
    }

    /**
     * Handles the $employee workflow event as a listener.
     *
     * @param EmployeeWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(EmployeeWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
