<?php
namespace Bixo\Employee\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Employee\Events\EmployeeAction as EmployeeActionEvent;
use Bixo\Employee\Models\Employee;

class EmployeeAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $employee;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param EmployeeActionEvent $employee
     */
    public function __construct(EmployeeActionEvent $employee)
    {
        $this->action = $event->action;
        $this->employee = $employee;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Employee Approved - ' . config('app.name'))
            ->view('employee::employee.email.action', ['data' => $this->employee]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
