<?php

namespace Bixo\Employee\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Employee\Models\Attendance;

class AttendancePolicy
{

    use AttendanceAction;
    use AttendanceReport;
    use AttendanceWorkflow;

    /**
     * Determine if the given user can view the attendance.
     *
     * @param Authenticatable $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function view(Authenticatable $user, Attendance $attendance)
    {
        if ($authUser->canDo('employee.attendance.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $attendance->is_owner;
    }

    /**
     * Determine if the given user can create a attendance.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('employee.attendance.create');
    }

    /**
     * Determine if the given user can update the given attendance.
     *
     * @param Authenticatable $user
     * @param Attendance $attendance
     *
     * @return bool
     */
    public function update(Authenticatable $user, Attendance $attendance)
    {
        if ($user->canDo('employee.attendance.edit') && $user->isAdmin()) {
            return true;
        }

        return $attendance->is_owner;
    }

    /**
     * Determine if the given user can delete the given attendance.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Attendance $attendance)
    {
        return $attendance->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
