<?php

namespace Bixo\Employee\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Employee\Models\Employee;

class EmployeePolicy
{

    use EmployeeAction;
    use EmployeeReport;
    use EmployeeWorkflow;

    /**
     * Determine if the given user can view the employee.
     *
     * @param Authenticatable $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function view(Authenticatable $user, Employee $employee)
    {
        if ($authUser->canDo('employee.employee.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $employee->is_owner;
    }

    /**
     * Determine if the given user can create a employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('employee.employee.create');
    }

    /**
     * Determine if the given user can update the given employee.
     *
     * @param Authenticatable $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function update(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.edit') && $user->isAdmin()) {
            return true;
        }

        return $employee->is_owner;
    }

    /**
     * Determine if the given user can delete the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Employee $employee)
    {
        return $employee->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
