<?php

namespace Bixo\Employee\Policies;

use Bixo\Employee\Models\Employee;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait EmployeeWorkflow
{

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.reject')) {
            return true;
        }

        return false;
    }

}
