<?php

namespace Bixo\Employee\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Employee\Models\Leave;

class LeavePolicy
{

    use LeaveAction;
    use LeaveReport;
    use LeaveWorkflow;

    /**
     * Determine if the given user can view the leave.
     *
     * @param Authenticatable $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function view(Authenticatable $user, Leave $leave)
    {
        if ($authUser->canDo('employee.leave.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $leave->is_owner;
    }

    /**
     * Determine if the given user can create a leave.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('employee.leave.create');
    }

    /**
     * Determine if the given user can update the given leave.
     *
     * @param Authenticatable $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function update(Authenticatable $user, Leave $leave)
    {
        if ($user->canDo('employee.leave.edit') && $user->isAdmin()) {
            return true;
        }

        return $leave->is_owner;
    }

    /**
     * Determine if the given user can delete the given leave.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Leave $leave)
    {
        return $leave->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
