<?php

namespace Bixo\Employee\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Bixo\Employee\Models\Employee;
use Bixo\Employee\Models\Document;
use Bixo\Employee\Models\Attendance;
use Bixo\Employee\Models\Leave;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Employee\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/employee/employee/*')) {
            Route::bind('employee', function ($employee) {
                return Employee::findorNew($employee);
            });
        }
        if (Request::is('*/employee/document/*')) {
            Route::bind('document', function ($document) {
                return Document::findorNew($document);
            });
        }
        if (Request::is('*/employee/attendance/*')) {
            Route::bind('attendance', function ($attendance) {
                return Attendance::findorNew($attendance);
            });
        }
        if (Request::is('*/employee/leave/*')) {
            Route::bind('leave', function ($leave) {
                return Leave::findorNew($leave);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
